package shiroExample;

import org.apache.shiro.config.ConfigurationException;
import org.apache.shiro.config.Ini;
import org.apache.shiro.config.IniSecurityManagerFactory;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.mgt.SecurityManager;
import org.apache.shiro.util.Factory;

public class SecurityManagerSetup
{
   private static boolean securityManagerInitialized = false;
   
   private static void setupIni( Ini ini, String iniFile )
		                                          throws ConfigurationException
   {
      if( iniFile != null )
      {
    	 System.out.println( "Attempting to load from file:" + iniFile );
    	 
    	 try
    	 {
       	    ini.loadFromPath( "file:" + iniFile );
    	 }
    	 catch( ConfigurationException ce )
    	 {
    		 System.out.println( "ini.loadFromPath() failed with error: " + ce.getMessage() );
    	 }
      }
      else
      {
         throw new ConfigurationException( "No iniFile specified" );
      }
   }
   
   public static void initSecurity( String iniFile )
                                                  throws ConfigurationException
   {
	  if( !SecurityManagerSetup.securityManagerInitialized )
	  {
         /*******************************************************
          * Set up the Security Manager.
          *******************************************************/
          Ini ini = new Ini();

          try
          {
             SecurityManagerSetup.setupIni( ini, iniFile );
          }
          catch( ConfigurationException ce )
          {
        	  System.out.println( "SecurityManagerSetup.setupIni() failed: "
                                + ce.getMessage() );
        	  throw ce;
          }
          
         /* Read the shiro.ini file */
         Factory<SecurityManager> factory =
           (Factory<SecurityManager>)new IniSecurityManagerFactory( ini );
//                  "file:C:\\Users\\calynch\\workspace\\ShiroExample\\src\\shiro.ini" );

         /* Parse the shiro.ini file and create a SecurityManager object which
          * contains the configuration information specified in the file.
          */
         SecurityManager securityManager  = factory.getInstance();

         /* Set the SecurityManager object to be static (memory) singleton,
          * accessible across the JVM.
          */
         SecurityUtils.setSecurityManager( securityManager );

         SecurityManagerSetup.securityManagerInitialized = true;
      }
   }
}
