package shiroExample;

import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.IncorrectCredentialsException;
import org.apache.shiro.authc.LockedAccountException;
import org.apache.shiro.authc.UnknownAccountException;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.subject.Subject;
import org.apache.shiro.session.Session;

public class SecuritySession
{
   private       Subject currentUser;
   private       Session session;
   private final String  key   = "someKey";
   private final String  value = "aValue";
   
   public SecuritySession()
   {
	   this.currentUser = SecurityUtils.getSubject();
	   this.session     = this.currentUser.getSession();
	   this.session.setAttribute( this.key, this.value );
   }
   
   public String getValue()
   {
      return( (String)this.session.getAttribute( this.key ) );
   }
   
   public SecurityError login( String userName, String password )
   {
	  SecurityError error = SecurityError.SECURITY_ERROR_NONE;
	  
      if( !currentUser.isAuthenticated() )
      {
         UsernamePasswordToken token = new UsernamePasswordToken( userName,
                                                                  password );
         token.setRememberMe( true );
		   
         try
         {
            this.currentUser.login( token );
         }
         catch( UnknownAccountException uae )
         {
        	 error = SecurityError.SECURITY_ERROR_UNKNOWN_ACCOUNT;
         }
         catch( IncorrectCredentialsException ice )
         {
        	 error = SecurityError.SECURITY_ERROR_INCORRECT_CREDENTIALS;
         }
         catch( LockedAccountException lae )
         {
        	 error = SecurityError.SECURITY_ERROR_LOCKED_ACCOUNT;
         }
         catch( AuthenticationException ae )
         {
        	 error = SecurityError.SECURITY_ERROR_AUTHENTICATION;
         }
      }
      else
      {
    	  error = SecurityError.SECURITY_ERROR_NOT_AUTHENTICATED;
      }
      
      return( error );
   }
   
   public boolean hasRole( String userName )
   {
      if( this.currentUser.hasRole( userName ) )
      {
    	  return( true );
      }
      
      return( false );
   }
   
   public boolean isPermitted( String action )
   {
	   if( this.currentUser.isPermitted( action ) )
	   {
		   return( true );
	   }
	   
	   return( false );
   }
}
